@@ -11,7 +11,7 @@ except ImportError:
 if __HAS_SQLALCHEMY:
 
     from sqlalchemy import create_engine
-    from sqlalchemy.orm import sessionmaker, EXT_CONTINUE, SessionExtension
+    from sqlalchemy.orm import sessionmaker, EXT_CONTINUE, SessionExtension, scoped_session
     from sqlalchemy.exceptions import InvalidRequestError
 
 
@@ -116,12 +116,12 @@ class SqlAlchemyStore(BaseStore):
             
             if engine:
                 # we have an engine, we can create the bound session now
-                self.__session = sessionmaker(autoflush=True, bind=engine)()
+                self.__session = scoped_session(sessionmaker(autoflush=True, bind=engine))
             
             else:
                 # no engine or URI was specified, create an unbound session
                 # (mapped object metadata will need to be bound to an engine in this case)
-                self.__session = sessionmaker(autoflush=True)()
+                self.__session = scoped_session(sessionmaker(autoflush=True))
     
     def put(self, obj):
         # only store SA objects
