@@ -18,6 +18,7 @@ if __HAVE_SA:
     from stockpyle._chained import ChainedStore
     from stockpyle._procmem import ProcessMemoryStore
     from stockpyle._sqlalchemy import SqlAlchemyStore, StockpyleSessionExtension
+    from stockpyle.exceptions import NonUniqueKeyError
     
     
     class Bazbot(DeclarativeBase):
@@ -352,3 +353,13 @@ if __HAVE_SA:
             # but the persistent get should also work
             obj_r = self.__sa.get(Bazbot, {"zap": 3})
             self.assertEqual(obj_r, obj)
+        
+        def test_queries_that_return_multiple_entities_throw_nonunique_error(self):
+            barval = 2
+            obj1 = Bazbot(1,barval,3)
+            obj2 = Bazbot(1,barval,4)
+            self.assertEqual(obj1.bar, 2)
+            self.assertEqual(obj2.bar, 2)
+            self.__sa.batch_put([obj1, obj2])
+            self.assertRaises(NonUniqueKeyError, lambda: self.__sa.get(Bazbot, {"bar": barval}))
+            
